summaryrefslogtreecommitdiffhomepage
path: root/examples/models
diff options
context:
space:
mode:
authorRay San <[email protected]>2017-10-17 11:51:50 +0200
committerRay San <[email protected]>2017-10-17 11:51:50 +0200
commit5dc216f4196603a9b5951b596ac2b9b0e84d56e3 (patch)
tree25da3d9671843713029e5c2de4d50e390ff964fa /examples/models
parentb065edc8785a5a7aca3dfe79163b15aa7a0d6883 (diff)
downloadraylib-5dc216f4196603a9b5951b596ac2b9b0e84d56e3.tar.gz
raylib-5dc216f4196603a9b5951b596ac2b9b0e84d56e3.zip
Improved some examples
Diffstat (limited to 'examples/models')
-rw-r--r--examples/models/models_material_pbr.pngbin193874 -> 324224 bytes
-rw-r--r--examples/models/models_mesh_generation.c74
-rw-r--r--examples/models/models_yaw_pitch_roll.png (renamed from examples/models/models_plane_rotations.png)bin183992 -> 183992 bytes
3 files changed, 49 insertions, 25 deletions
diff --git a/examples/models/models_material_pbr.png b/examples/models/models_material_pbr.png
index cde171b9..86ba01b0 100644
--- a/examples/models/models_material_pbr.png
+++ b/examples/models/models_material_pbr.png
Binary files differ
diff --git a/examples/models/models_plane_rotations.png b/examples/models/models_yaw_pitch_roll.png
index 5400304d..5400304d 100644
--- a/examples/models/models_plane_rotations.png
+++ b/examples/models/models_yaw_pitch_roll.png
Binary files differ
diff --git a/examples/models/models_mesh_generation.c b/examples/models/models_mesh_generation.c
index 2b3d5c5f..72222156 100644
--- a/examples/models/models_mesh_generation.c
+++ b/examples/models/models_mesh_generation.c
@@ -11,9 +11,8 @@
#include "raylib.h"
-//------------------------------------------------------------------------------------
-// Program main entry point
-//------------------------------------------------------------------------------------
+#define NUM_MODELS 7 // We generate 7 parametric 3d shapes
+
int main()
{
// Initialization
@@ -23,33 +22,35 @@ int main()
InitWindow(screenWidth, screenHeight, "raylib [models] example - mesh generation");
- //Model model = LoadModelFromMesh(GenMeshPlane(2, 2, 5, 5)); // Texture coordinates must be divided by resX, resZ
- //Model model = LoadModelFromMesh(GenMeshCube(2.0f, 1.0f, 2.0f)); // OK!
- //Model model = LoadModelFromMesh(GenMeshSphere(2, 32, 32)); // OK! (par_shapes)
- //Model model = LoadModelFromMesh(GenMeshHemiSphere(2, 16, 16)); // OK! (par_shapes)
- //Model model = LoadModelFromMesh(GenMeshCylinder(1, 2, 16)); // OK! (par_shapes)
- Model model = LoadModelFromMesh(GenMeshTorus(0.25f, 4.0f, 16, 32));
- //Model model = LoadModelFromMesh(GenMeshKnot(1.0f, 2.0f, 16, 128));
- model.material.maps[MAP_DIFFUSE].texture = LoadTexture("resources/pixels.png");
-
- // Debug information
- /*
- printf("model.mesh.vertexCount: %i\n", model.mesh.vertexCount);
- printf("model.mesh.triangleCount: %i\n", model.mesh.triangleCount);
- printf("model.mesh.vboId (position): %i\n", model.mesh.vboId[0]);
- printf("model.mesh.vboId (texcoords): %i\n", model.mesh.vboId[1]);
- printf("model.mesh.vboId (normals): %i\n", model.mesh.vboId[2]);
- printf("model.mesh.vboId (indices): %i\n", model.mesh.vboId[6]);
- */
+ // We generate a checked image for texturing
+ Image checked = GenImageChecked(2, 2, 1, 1, RED, GREEN);
+ Texture2D texture = LoadTextureFromImage(checked);
+ UnloadImage(checked);
+
+ Model models[NUM_MODELS];
+
+ models[0] = LoadModelFromMesh(GenMeshPlane(2, 2, 5, 5));
+ models[1] = LoadModelFromMesh(GenMeshCube(2.0f, 1.0f, 2.0f));
+ models[2] = LoadModelFromMesh(GenMeshSphere(2, 32, 32));
+ models[3] = LoadModelFromMesh(GenMeshHemiSphere(2, 16, 16));
+ models[4] = LoadModelFromMesh(GenMeshCylinder(1, 2, 16));
+ models[5] = LoadModelFromMesh(GenMeshTorus(0.25f, 4.0f, 16, 32));
+ models[6] = LoadModelFromMesh(GenMeshKnot(1.0f, 2.0f, 16, 128));
+ // Set checked texture as default diffuse component for all models material
+ for (int i = 0; i < NUM_MODELS; i++) models[i].material.maps[MAP_DIFFUSE].texture = texture;
+
// Define the camera to look into our 3d world
Camera camera = {{ 5.0f, 5.0f, 5.0f }, { 0.0f, 0.0f, 0.0f }, { 0.0f, 1.0f, 0.0f }, 45.0f };
+ // Model drawing position
Vector3 position = { 0.0f, 0.0f, 0.0f };
- SetCameraMode(camera, CAMERA_FREE); // Set a free camera mode
+ int currentModel = 0;
+
+ SetCameraMode(camera, CAMERA_ORBITAL); // Set a orbital camera mode
- SetTargetFPS(60); // Set our game to run at 60 frames-per-second
+ SetTargetFPS(60); // Set our game to run at 60 frames-per-second
//--------------------------------------------------------------------------------------
// Main game loop
@@ -58,6 +59,11 @@ int main()
// Update
//----------------------------------------------------------------------------------
UpdateCamera(&camera); // Update internal camera and our camera
+
+ if (IsMouseButtonPressed(MOUSE_LEFT_BUTTON))
+ {
+ currentModel = (currentModel + 1)%NUM_MODELS; // Cycle between the textures
+ }
//----------------------------------------------------------------------------------
// Draw
@@ -68,11 +74,27 @@ int main()
Begin3dMode(camera);
- DrawModel(model, position, 1.0f, WHITE);
+ DrawModel(models[currentModel], position, 1.0f, WHITE);
DrawGrid(10, 1.0);
End3dMode();
+
+ DrawRectangle(30, 400, 310, 30, Fade(SKYBLUE, 0.5f));
+ DrawRectangleLines(30, 400, 310, 30, Fade(DARKBLUE, 0.5f));
+ DrawText("MOUSE LEFT BUTTON to CYCLE PROCEDURAL MODELS", 40, 410, 10, BLUE);
+
+ switch(currentModel)
+ {
+ case 0: DrawText("PLANE", 680, 10, 20, DARKBLUE); break;
+ case 1: DrawText("CUBE", 680, 10, 20, DARKBLUE); break;
+ case 2: DrawText("SPHERE", 680, 10, 20, DARKBLUE); break;
+ case 3: DrawText("HEMISPHERE", 640, 10, 20, DARKBLUE); break;
+ case 4: DrawText("CYLINDER", 680, 10, 20, DARKBLUE); break;
+ case 5: DrawText("TORUS", 680, 10, 20, DARKBLUE); break;
+ case 6: DrawText("KNOT", 680, 10, 20, DARKBLUE); break;
+ default: break;
+ }
EndDrawing();
//----------------------------------------------------------------------------------
@@ -80,7 +102,9 @@ int main()
// De-Initialization
//--------------------------------------------------------------------------------------
- UnloadModel(model);
+
+ // Unload models data (GPU VRAM)
+ for (int i = 0; i < NUM_MODELS; i++) UnloadModel(models[i]);
CloseWindow(); // Close window and OpenGL context
//--------------------------------------------------------------------------------------